MySQLdb Package
===============

:mod:`MySQLdb` Package
----------------------

.. automodule:: MySQLdb
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`MySQLdb.connections` Module
---------------------------------

.. automodule:: MySQLdb.connections
    :members: Connection
    :undoc-members:

:mod:`MySQLdb.converters` Module
--------------------------------

.. automodule:: MySQLdb.converters
    :members:
    :undoc-members:

:mod:`MySQLdb.cursors` Module
-----------------------------

.. automodule:: MySQLdb.cursors
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`MySQLdb.times` Module
---------------------------

.. automodule:: MySQLdb.times
    :members:
    :undoc-members:

:mod:`MySQLdb._mysql` Module
----------------------------

.. automodule:: MySQLdb._mysql
    :members:
    :undoc-members:

:mod:`MySQLdb._exceptions` Module
---------------------------------

.. automodule:: MySQLdb._exceptions
    :members:
    :undoc-members:


Subpackages
-----------

.. toctree::

    MySQLdb.constants

